=========
crystalpy
=========

About
-----

Python tools for X-ray diffraction in perfect crystals.

Contains code to calculate diffraction for perfect crystals using dynamical diffraction theory. It uses the Zachariasen formalism. It contain tools to simulate polarization of crystals by Mueller/Stokes optics.


Documentation
-------------
https://crystalpy.readthedocs.io/


Source repository
-----------------
https://github.com/oasys-kit/crystalpy

Quick-installation
------------------

Crystalpy can be installed with Python 3.x:

.. code-block:: console

    $ python -m pip install crystalpy

Reference
---------

J-P Guigay and M Sanchez del Rio "Diffracted amplitudes for perfect crystals derived from solutions of Takagi-Taupin equations and numerical implementation in the crystalpy library."
(In preparation).

Other Documents
---------------

The Ms Thesis related to this project is https://github.com/oasys-kit/documents/blob/master/cappelli-tesi.pdf


Graphical user interface
------------------------

A graphical interface is available under Oasys:  https://github.com/oasys-kit/OASYS-CRYSTALPY
